import { Client } from '@searchspring/snap-client';
import { Logger } from '@searchspring/snap-logger';
import { Tracker } from '@searchspring/snap-tracker';
import { ControllerTypes } from '@searchspring/snap-controller';
import type { ClientConfig, ClientGlobals } from '@searchspring/snap-client';
import type { AbstractController, SearchController, AutocompleteController, FinderController, RecommendationController, SearchControllerConfig, AutocompleteControllerConfig, FinderControllerConfig, RecommendationControllerConfig, ControllerConfigs, ContextVariables } from '@searchspring/snap-controller';
import type { Target, OnTarget } from '@searchspring/snap-toolbox';
import type { UrlTranslatorConfig } from '@searchspring/snap-url-manager';
import { RecommendationInstantiator, RecommendationInstantiatorConfig } from './Instantiators/RecommendationInstantiator';
import type { SnapControllerServices, RootComponent } from './types';
export declare const BRANCH_COOKIE = "ssBranch";
export declare const SS_DEV_COOKIE = "ssDev";
declare type ExtendedTarget = Target & {
    name?: string;
    controller?: AbstractController;
    component?: () => Promise<RootComponent> | RootComponent;
    skeleton?: () => Promise<any>;
    props?: unknown;
    onTarget?: OnTarget;
    prefetch?: boolean;
};
export declare type SnapConfig = {
    context?: ContextVariables;
    url?: UrlTranslatorConfig;
    client?: {
        globals: ClientGlobals;
        config?: ClientConfig;
    };
    instantiators?: {
        recommendation?: RecommendationInstantiatorConfig;
    };
    controllers?: {
        search?: {
            config: SearchControllerConfig;
            targeters?: ExtendedTarget[];
            services?: SnapControllerServices;
            url?: UrlTranslatorConfig;
            context?: ContextVariables;
        }[];
        autocomplete?: {
            config: AutocompleteControllerConfig;
            targeters?: ExtendedTarget[];
            services?: SnapControllerServices;
            url?: UrlTranslatorConfig;
            context?: ContextVariables;
        }[];
        finder?: {
            config: FinderControllerConfig;
            targeters?: ExtendedTarget[];
            services?: SnapControllerServices;
            url?: UrlTranslatorConfig;
            context?: ContextVariables;
        }[];
        recommendation?: {
            config: RecommendationControllerConfig;
            targeters?: ExtendedTarget[];
            services?: SnapControllerServices;
            url?: UrlTranslatorConfig;
            context?: ContextVariables;
        }[];
    };
};
declare type SnapServices = {
    client?: Client;
    tracker?: Tracker;
    logger?: Logger;
};
declare type Controllers = SearchController | AutocompleteController | FinderController | RecommendationController;
export declare class Snap {
    config: SnapConfig;
    logger: Logger;
    client: Client;
    tracker: Tracker;
    context: ContextVariables;
    _controllerPromises: {
        [controllerConfigId: string]: Promise<Controllers>;
    };
    controllers: {
        [controllerConfigId: string]: Controllers;
    };
    _instantiatorPromises: {
        [instantiatorId: string]: Promise<RecommendationInstantiator>;
    };
    getInstantiator: (id: string) => Promise<RecommendationInstantiator>;
    getController: (id: string) => Promise<Controllers>;
    getControllers: (...controllerIds: string[]) => Promise<Controllers[]>;
    createController: (type: keyof typeof ControllerTypes, config: ControllerConfigs, services?: SnapControllerServices, urlConfig?: UrlTranslatorConfig, context?: ContextVariables, callback?: (value?: Controllers | PromiseLike<Controllers>) => void | Promise<void>) => Promise<Controllers>;
    constructor(config: SnapConfig, services?: SnapServices);
}
export {};
//# sourceMappingURL=Snap.d.ts.map